@@ -4,8 +4,8 @@ class Folder:
         self._py_client = py_client
         self._folder_json = folder_json
 
-    def get_id(self):
-        """Returns the folder's id."""
+    def get_oid(self):
+        """Returns the folder's oid."""
         return self._folder_json['oid']
 
     def get_name(self):
